==> nextcloud-29.0.9.tar.bz2: nextcloud/apps/photos/l10n/ko.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "공개 링크",
    "Photos" : "사진",
    "All media" : "모든 미디어",
    "Videos" : "동영상",
    "Albums" : "앨범",
    "Collaborative albums" : "협업 앨범",
    "People" : "사람들",
    "Folders" : "폴더",
    "Favorites" : "즐겨찾기",
    "On this day" : "이맘때",
    "Shared with you" : "나와 공유됨",
    "Tags" : "태그",
    "Places" : "장소",
    "Map" : "지도",
    "Name of the album" : "앨범의 이름",
    "Location of the album" : "앨범의 위치",
    "Back" : "뒤로",
    "Add collaborators" : "공동 작업자 추가",
    "Save" : "저장",
    "Create album" : "앨범 만들기",
    "Add selection to album {albumName}" : "{albumName} 앨범을 선택하기",
    "Shared by" : "다음 사용자가 공유함",
    "Create a new album." : "새 앨범 만들기",
    "Create new album" : "새 앨범 만들기",
    "New album" : "새 앨범",
    "Add people or groups who can edit your album" : "앨범을 수정할 수 있는 사람 및 그룹 추가",
    "Search people or groups" : "사람 및 그룹 검색",
    "No recommendations. Start typing." : "추천 없음. 타이핑을 시작하십시오",
    "Remove {collaboratorLabel} from the collaborators list" : "공동 작업자 목록에서 {collaboratorLabel} 제거",
    "Copy the public link" : "공개 링크 복사",
    "Public link copied!" : "공개 링크 복사!",
    "Copy public link" : "공개 링크 복사",
    "Delete the public link" : "공개 링크 삭제",
    "Share via public link" : "공개 링크로 공유",
    "Failed to fetch collaborators list." : "공동 작업자 목록을 가져오기에 실패했습니다.",
    "Failed to update album." : "앨범 업데이트에 실패했습니다.",
    "An error occurred" : "오류가 발생함",
    "Favorite" : "즐겨찾기",
    "Go back" : "뒤로 가기",
    "Dates" : "날짜",
    "Add folder" : "폴더 추가",
    "Home" : "집",
    "View" : "보기",
    "Unselect all" : "모두 선택 해제",
    "Edit album details" : "앨범 세부 정보 수정",
    "Delete album" : "앨범 삭제",
    "Save collaborators for this album." : "앨범의 공동 작업자를 저장",
    "Rename person" : "사람 제거",
    "Merge with different person" : "다른 사람에게 병합",
    "Remove from favorites" : "즐겨찾기에서 제거",
    "Remove person" : "사람 제거",
    "Add" : "추가",
    "Add to album" : "앨범에 추가",
    "Delete selection" : "선택 항목 삭제",
    "Unassigned faces" : "지정되지 않은 얼굴",
    "Details" : "세부사항",
    "Failed to delete {fileName}." : "{fileName}(을)를 삭제하지 못했습니다.",
    "Invalid location selected" : "잘못된 위치가 선택됨"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.8.tar.bz2: nextcloud/apps/photos/l10n/ko.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "공개 링크",
    "Photos" : "사진",
    "All media" : "모든 미디어",
    "Videos" : "동영상",
    "Albums" : "앨범",
    "Collaborative albums" : "협업 앨범",
    "People" : "사람들",
    "Folders" : "폴더",
    "Favorites" : "즐겨찾기",
    "On this day" : "이맘때",
    "Shared with you" : "나와 공유됨",
    "Tags" : "태그",
    "Places" : "장소",
    "Map" : "지도",
    "Name of the album" : "앨범의 이름",
    "Location of the album" : "앨범의 위치",
    "Back" : "뒤로",
    "Add collaborators" : "공동 작업자 추가",
    "Save" : "저장",
    "Create album" : "앨범 만들기",
    "Add selection to album {albumName}" : "{albumName} 앨범을 선택하기",
    "Shared by" : "다음 사용자가 공유함",
    "Create a new album." : "새 앨범 만들기",
    "Create new album" : "새 앨범 만들기",
    "New album" : "새 앨범",
    "Failed to fetch collaborators list." : "공동 작업자 목록을 가져오기에 실패했습니다.",
    "Failed to update album." : "앨범 업데이트에 실패했습니다.",
    "Add people or groups who can edit your album" : "앨범을 수정할 수 있는 사람 및 그룹 추가",
    "Search people or groups" : "사람 및 그룹 검색",
    "No recommendations. Start typing." : "추천 없음. 타이핑을 시작하십시오",
    "Remove {collaboratorLabel} from the collaborators list" : "공동 작업자 목록에서 {collaboratorLabel} 제거",
    "Copy the public link" : "공개 링크 복사",
    "Public link copied!" : "공개 링크 복사!",
    "Copy public link" : "공개 링크 복사",
    "Delete the public link" : "공개 링크 삭제",
    "Share via public link" : "공개 링크로 공유",
    "An error occurred" : "오류가 발생함",
    "Favorite" : "즐겨찾기",
    "Go back" : "뒤로 가기",
    "Dates" : "날짜",
    "All folders" : "모든 폴더",
    "Add folder" : "폴더 추가",
    "Home" : "집",
    "View" : "보기",
    "Unselect all" : "모두 선택 해제",
    "Edit album details" : "앨범 세부 정보 수정",
    "Delete album" : "앨범 삭제",
    "Save collaborators for this album." : "앨범의 공동 작업자를 저장",
    "Rename person" : "사람 제거",
    "Merge with different person" : "다른 사람에게 병합",
    "Remove from favorites" : "즐겨찾기에서 제거",
    "Remove person" : "사람 제거",
    "Add to album" : "앨범에 추가",
    "Delete selection" : "선택 항목 삭제",
    "Unassigned faces" : "지정되지 않은 얼굴",
    "Details" : "세부사항",
    "Add" : "추가"
},
"nplurals=1; plural=0;");
